@@ -14,7 +14,7 @@ import requests
 from lxml import html
 from wand.image import Image
 
-version = '0.58.4'
+version = '0.58.5'
 
 user_agent = {"User-Agent": "git.io/wanda"}
 content_json = "application/json"
@@ -81,7 +81,7 @@ def parser():
 
 
 def is_connected():
-    return requests.get("https://detectportal.firefox.com/success.txt") == "success"
+    return requests.get("https://detectportal.firefox.com/success.txt").text.strip() == "success"
 
 
 def validate_url(url):
@@ -103,9 +103,13 @@ def short_url(url: str) -> str:
     return f"{response['result_url']}" if "result_url" in response else url
 
 
+def is_web_url(url):
+    return url.startswith("https://")
+
+
 def set_wp(url: str, home=True, lock=True):
     if is_android():
-        t = "u" if url.startswith("https://") else "f"
+        t = "u" if is_web_url(url) else "f"
         if home:
             command(f"termux-wallpaper -{t} {url}")
         if lock:
@@ -242,21 +246,25 @@ def blank(search):
 
 
 def fourchan(search=None):
-    if "@" not in search:
-        search = f"subject={search}" if search else ""
+    if not search:
+        search = ""
+        board = "wg"
+    elif "@" not in search:
+        search = f"{search}" if search else ""
         board = "wg"
     else:
-        search = search.split("@")[0]
         board = search.split("@")[1]
-    if is_portrait():
-        search = f"{search} {random.choice(['phone', 'mobile'])}".strip()
-    api = f"https://archive.alice.al/_/api/chan/search/?boards={board}&{search}"
-    posts = requests.get(api).json()["0"]["posts"]
-    posts = list(filter(lambda p: "media" in p and "nimages" in p, posts))
+        search = search.split("@")[0]
+
+    api = f"https://archive.alice.al/_/api/chan/search/?boards={board}&subject={search}"
+    response = requests.get(api).json()
+    if "error" in response:
+        no_results()
+    posts = list(filter(lambda p: "media" in p and "nimages" in p, response["0"]["posts"]))
     if not posts:
         no_results()
     post = random.choice(posts)
-    thread = post["num"]
+    thread = post["thread_num"]
     board = post["board"]["shortname"]
     api = f"https://archive.alice.al/_/api/chan/thread/?board={board}&num={thread}"
     posts = requests.get(api).json()[thread]["posts"]
@@ -287,14 +295,13 @@ def is_imgur_gallery(url):
     return contains(url, False, ["imgur.com/a", "imgur.com/gallery"])
 
 
-def reddit_search(sub, search=None):
+def reddit_search(sub, search=None, extra=""):
     base = "https://old.reddit.com/r/"
-    if search:
-        common_param = "&restrict_sr=on&sort=relevance&t=all&sort=top&limit=100&type=link"
-        search_api = "/search.json?q="
-        return f"{base}{sub}{search_api}{search}{common_param}"
-    else:
-        return f"{base}{sub}.json"
+    if not search:
+        return f"{base}{sub}.json?{extra}"
+    common_param = f"&restrict_sr=on&sort=relevance&t=all&sort=top&limit=100&type=link{extra}"
+    search_api = "/search.json?q="
+    return f"{base}{sub}{search_api}{search}{common_param}"
 
 
 def reddit_compare_image_size(title):
@@ -306,15 +313,17 @@ def reddit_compare_image_size(title):
 
 
 def reddit(search=None, subreddits=subreddit()):
-    if "@" in search:
-        search = search.split("@")[0]
+    if search and "@" in search:
         subreddits = search.split("@")[1]
-    api = f"{reddit_search(subreddits, search)}"
+        search = search.split("@")[0]
+    api = reddit_search(subreddits, search)
     posts = requests.get(api, headers=user_agent).json()["data"]["children"]
-    image_urls = ["reddit.com/gallery", "imgur.com/a", "imgur.com/gallery"]
+    image_urls = ["reddit.com/gallery", "imgur.com/a", "imgur.com/gallery", "i.redd.it", "i.imgur", ]
     posts = list(filter(lambda p:
                         contains(p["data"]["url"], False, image_urls) and
                         reddit_compare_image_size(p["data"]["title"]), posts))
+    if not posts:
+        no_results()
     url = random.choice(posts)["data"]["url"]
     if "reddit.com/gallery" in url:
         return random.choice(reddit_gallery(url))
@@ -327,34 +336,26 @@ def reddit(search=None, subreddits=subreddit()):
 
 
 def imgur(search=None):
-    alt = "rimgo.pussthecat.org"
-    if search and not search.islower():
-        imgur_url = f"https://{alt}/gallery/{search}"
+    if search:
+        imgur_url = f"https://rimgo.pussthecat.org/gallery/{search}"
     else:
-        api = reddit_search("wallpaperdump", search)
+        search = ""
         if is_portrait():
-            search = f"{search or ''} {random.choice(['phone', 'mobile'])}"
-            api = f"{reddit_search('wallpaperdump', search)}"
-        imgur_url = ""
-        while not contains(imgur_url, True, ["imgur.com"]):
-            response = requests.get(api, headers=user_agent).json()["data"]["children"]
-            imgur_url = random.choice(response)["data"]["url"] if response else no_results()
+            search = f"&q={search or ''} {random.choice(['phone', 'mobile'])}"
+        api = f"https://old.reddit.com/r/wallpaperdump/search.json?q=site:imgur.com&restrict_sr=on{search}"
+        response = requests.get(api, headers=user_agent).json()["data"]["children"]
+        imgur_url = random.choice(response)["data"]["url"] if response else no_results()
 
-    return get_imgur_image(alt, imgur_url)
+    return get_imgur_image(imgur_url)
 
 
 def get_imgur_image(imgur_url, alt="rimgo.pussthecat.org"):
-    tree = html.fromstring(requests.get(imgur_url.replace("imgur.com", f"{alt}")).content)
+    tree = html.fromstring(
+        requests.get(imgur_url.replace("imgur.com", f"{alt}"), headers=user_agent).content)
     images = tree.xpath("//div[@class='center']//img/@src")
     return f"https://{alt}{random.choice(images)}" if images else no_results()
 
 
-def imsea(search=None):
-    api = f"https://imsea.herokuapp.com/api/1?q={size}+{search or 'wallpaper'}"
-    response = requests.get(api).json()["results"]
-    return random.choice(response) if response else no_results()
-
-
 def fivehundredpx(search=None):
     payload = {
         "operationName": "PhotoSearchQueryRendererQuery",
@@ -404,7 +405,8 @@ def artstation_prints(search=None):
 
 def artstation_artist(search=None):
     import cloudscraper
-
+    if blank(search):
+        search = random.choice(["tohad"])
     scraper = cloudscraper.create_scraper()
     response = scraper.get(f"https://www.artstation.com/users/{search}/hovercard.json", headers=user_agent)
     if response.status_code != 200:
@@ -445,7 +447,10 @@ def artstation_any(search=None):
 
 
 def local(path):
-    if not path.endswith("/"):
+    if blank(path):
+        print("Please specify path to images")
+        exit(1)
+    if path and not path.endswith("/"):
         path = f'{path}/'
     if os.path.exists(path):
         return path + random.choice(list(filter(lambda f: f.endswith(".png") or f.endswith(".jpg"), os.listdir(path))))
@@ -477,8 +482,7 @@ def usage():
     print(f"{cyan}arstation {pink}[keyword]")
     print(f"{cyan}arstation_{cyan}artist {pink}[id of artist. example: aenamiart]")
     print(f"{cyan}arstation_{cyan}prints {pink}[keyword for prints]")
-    print(f"{cyan}imgur {pink}[gallery id. example: qF259WO]|[keyword]")
-    print(f"{cyan}imsea {pink}[keyword]")
+    print(f"{cyan}imgur {pink}[gallery id. example: qF259WO]")
     print(f"{cyan}earthview")
     print(f"{cyan}local {pink}[full path to folder]")
     print(f"{cyan}reddit {pink}[keyword]|[keyword@subreddit]")
@@ -519,6 +523,9 @@ def run():
         home = True
 
     try:
+        if source != 'local' and not is_connected():
+            print("Please check your internet connection and try again")
+            exit(1)
         set_wp(eval(source_map(source))(term), home, lock)
     except NameError:
         print(f"Unknown source: '{source}'. Available sources:")
@@ -534,7 +541,6 @@ def shortcodes():
         "ap": "artstation_prints",
         "a": "artstation",
         "e": "earthview",
-        "im": "imsea",
         "i": "imgur",
         "l": "local",
         "r": "reddit",
